@@ -13,9 +13,9 @@ def factory_data_load_and_split(filename, target, predictor, test_size=0.33, red
     Healthcare NHS Foundation Trust or other trusts who use the theme ("Access", "Environment/ facilities" etc.) and
     criticality labels. They can otherwise be safely ignored.
 
-    :param str, pandas.DataFrame filename: A ``pandas.DataFrame`` with the data, otherwise the dataset name (CSV),
-        including full path to the data folder (if not in the project's working directory), and the data type suffix
-        (".csv"). If ``filename`` is ``None``, the data are read from the database.
+    :param str, pandas.DataFrame filename: A ``pandas.DataFrame`` with the data (class and text columns), otherwise the
+        dataset name (CSV), including full path to the data folder (if not in the project's working directory), and the
+        data type suffix (".csv"). If ``filename`` is ``None``, the data are read from the database.
         **NOTE:** The feature that reads data from the database is for internal use only. Experienced users who would
         like to pull their data from their own databases can, of course, achieve that by slightly modifying the
         relevant lines in the script. A "my.conf" file will need to be placed in the root, with five lines, as follows
@@ -75,8 +75,7 @@ def factory_data_load_and_split(filename, target, predictor, test_size=0.33, red
     text_data = text_data.rename(columns={target: 'target', predictor: 'predictor'})
     if theme is not None:
         text_data = text_data.rename(columns={theme: 'theme'})
-    text_data = text_data.loc[text_data.target.notnull()].copy()
-    text_data = text_data.loc[text_data.target.notna()].copy()
+    text_data = text_data.dropna(subset=['target', 'predictor']).copy()
     text_data['predictor'] = text_data.predictor.fillna('__notext__')
 
     # This is specific to NHS patient feedback data labelled with "criticality" classes
